<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCrossSections</name>
    <message>
      <location filename="../../Command.cpp" line="269"/>
      <source>MeshPart</source>
      <translation>Ploskovje</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="270"/>
      <source>Cross-sections...</source>
      <translation>Prečni prerezi …</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="271"/>
      <source>Cross-sections</source>
      <translation>Prečni prerezi</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="305"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="306"/>
      <source>Curve on mesh...</source>
      <translation>Krivulja na ploskovju ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="307"/>
      <source>Creates an approximated curve on top of a mesh.
This command only works with a 'mesh' object.</source>
      <translation>Ustvari približno krivuljo po vrhu ploskovja.
Ta ukaz deluje le s "ploskovji".</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="59"/>
      <source>Create mesh from shape...</source>
      <translation>Ustvari ploskovje iz oblike …</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="60"/>
      <source>Tessellate shape</source>
      <translation>Teseliraj obliko</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location filename="../../Command.cpp" line="185"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="186"/>
      <source>Create section from mesh and plane</source>
      <translation>Ustvari prerez iz ploskovja in ravnine</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="187"/>
      <source>Section</source>
      <translation>Presek</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Trim mesh with a plane</source>
      <translation>Prireži ploskovje z ravnino</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="85"/>
      <location filename="../../Command.cpp" line="86"/>
      <source>Trims a mesh with a plane</source>
      <translation>Prireže ploskovje z ravnino</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="129"/>
      <source>Trim with plane</source>
      <translation>Prireži z ravnino</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Section with plane</source>
      <translation>Prerez z ravnino</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CrossSections</name>
    <message>
      <location filename="../../CrossSections.ui" line="14"/>
      <source>Cross sections</source>
      <translation>Prečni prerezi</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="20"/>
      <source>Guiding plane</source>
      <translation>Vodilna ravnina</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="26"/>
      <source>XY</source>
      <translation>XY</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="36"/>
      <source>XZ</source>
      <translation>XZ</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="43"/>
      <source>YZ</source>
      <translation>YZ</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="52"/>
      <source>Position:</source>
      <translation>Položaj:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="71"/>
      <source>Sections</source>
      <translation>Prerezi</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="83"/>
      <source>On both sides</source>
      <translation>Na obeh straneh</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="92"/>
      <source>Count</source>
      <translation>Število</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="109"/>
      <source>Distance:</source>
      <translation>Razdalja:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="128"/>
      <source>Options</source>
      <translation>Možnosti</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="134"/>
      <source>Connect edges if distance less than</source>
      <translation>Stakni robove, če je razdalja manjša od</translation>
    </message>
    <message>
      <location filename="../../CrossSections.cpp" line="366"/>
      <source>Failure</source>
      <translation>Napaka</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="364"/>
      <source>Create</source>
      <translation>Ustvari</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="366"/>
      <source>Close wire</source>
      <translation>Skledni črtovje</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="368"/>
      <source>Clear</source>
      <translation>Počisti</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="369"/>
      <source>Cancel</source>
      <translation>Prekliči</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="615"/>
      <source>Wrong mesh picked</source>
      <translation>Izbrano je napačno ploskovje</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="655"/>
      <source>No point was picked</source>
      <translation>Ni izbranih točk</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="14"/>
      <source>Curve on mesh</source>
      <translation>Krivulja na ploskovju</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="23"/>
      <source>Press 'Start', then pick points on the mesh; when enough points have been set, right-click and choose 'Create'. Repeat this process to create more splines. Close this task panel to complete the operation.

This command only works with a 'mesh' object, not a regular face or surface. To convert an object to a mesh use the tools of the Mesh Workbench.</source>
      <translation>Pritisnite "Začni" in nato izberite točke na ploskovju; ko je izbranih dovolj točk, kliknite z desno miškino tipko in izberite "Ustvari". Ponavljajte ta postopek, da ustvarite več zlepkov. Za dokončanje dejanja zaprite ta opravilni pult.

Ta ukaz deluje le na "ploskovjih" in ne na pravilnih ploskvah ali površjih. Če želite pretvoriti predmet v ploskovje, uporabi orodja delovnega okolja Ploskovje.</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="38"/>
      <source>Wire</source>
      <translation>Črtovje</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="44"/>
      <source>Snap tolerance to vertices</source>
      <translation>Dopustno odstopanje pri pripenjanju na oglišča</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="51"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="61"/>
      <source>Split threshold</source>
      <translation>Prag razdelitve</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="87"/>
      <source>Spline Approximation</source>
      <translation>Približek zlepku</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="96"/>
      <source>Tolerance to mesh</source>
      <translation>Dopustna odstopanja ploskovja</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="122"/>
      <source>Continuity</source>
      <translation>Zveznost</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="136"/>
      <source>Maximum curve degree</source>
      <translation>Najvišja stopnja krivulje</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="153"/>
      <source>Start</source>
      <translation>Začni</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="14"/>
      <source>Tessellation</source>
      <translation>Tlakovanje</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="20"/>
      <source>Meshing options</source>
      <translation>Možnosti ploskovjenja</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="30"/>
      <source>Standard</source>
      <translation>Običajno</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="33"/>
      <source>Use the standard mesher</source>
      <translation>Uporabi običajni ploskovjevalnik</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="41"/>
      <source>Surface deviation:</source>
      <translation>Odstopanje površja:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="48"/>
      <source>Maximal linear deflection of a mesh section from the surface of the object</source>
      <translation>Največje premo odstopanje odsekov ploskovja od površja predmeta</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="67"/>
      <source>Angular deviation:</source>
      <translation>Kotno odstopanje:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="74"/>
      <source>Maximal angular deflection of a mesh section to the next section</source>
      <translation>Največje odklon kota odseka ploskovja glede na sosednje ploskovje</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="98"/>
      <source>The maximal linear deviation of a mesh segment will be the specified
Surface deviation multiplied by the length of the current mesh segment (edge)</source>
      <translation>Določeno bo največje premo odstopanje odseka ploskovja
Odstopanje površja pomnoženo z dolžino trenutnega odseka ploskovja (rob)</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="102"/>
      <source>Relative surface deviation</source>
      <translation>Relativno odstopanje površja</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="109"/>
      <source>Mesh will get face colors of the object</source>
      <translation>Ploskovje bo prevzelo barve ploskev predmeta</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="112"/>
      <source>Apply face colors to mesh</source>
      <translation>Uporabi barve ploskev za ploskovje</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="119"/>
      <source>Mesh segments will be grouped according to the color of the object faces.
These groups will be exported for mesh output formats supporting
this feature (e.g. the format OBJ).</source>
      <translation>Odseki ploskovja podo zbrani glede na barvo ploskev predmeta.
Skupine se bodo izvozile za izhodne zapise, ki podpirajo te značilnosti (npr. zapis OBJ).</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="124"/>
      <source>Define segments by face colors</source>
      <translation>Določi odseke po barvi ploskve</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="145"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="148"/>
      <source>Use the Mefisto mesher</source>
      <translation>Uporabi ploskovjevalnik Mefisto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="156"/>
      <source>Maximum edge length:</source>
      <translation>Največja dolžina roba:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="162"/>
      <source>If this number is smaller the mesh becomes finer.
The smallest value is 0.</source>
      <translation>Manjša kot je številka, gostejše je ploskovje.
Najmanjša vrednost je 0.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="183"/>
      <source>Estimate</source>
      <translation>Ocena</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="206"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="209"/>
      <source>Use the Netgen mesher</source>
      <translation>Uporabi NetGAN ploskovjevalnik</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="217"/>
      <source>Fineness:</source>
      <translation>Podrobnost:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="234"/>
      <source>Very coarse</source>
      <translation>Zelo grobo</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="239"/>
      <source>Coarse</source>
      <translation>Groba</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="244"/>
      <source>Moderate</source>
      <translation>Zmerna</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="249"/>
      <source>Fine</source>
      <translation>Podroben</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="254"/>
      <source>Very fine</source>
      <translation>Zelo drobno</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="259"/>
      <source>User defined</source>
      <translation>Uporabniško določeno</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="269"/>
      <source>Mesh size grading:</source>
      <translation>Velikost gradnikov ploskovja:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="279"/>
      <source>If this parameter is smaller, the mesh becomes finer.
A value in the range of 0.1-1.</source>
      <translation>Če je ta določilka manjša, postane ploskvje drobnajše.
Razpon vrednosti je 0.1-1.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="302"/>
      <source>Elements per edge:</source>
      <translation>Število elementov na rob:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="312"/>
      <location filename="../../Tessellation.ui" line="345"/>
      <source>If this parameter is larger, the mesh becomes finer.
A value in the range of 0.2-10.</source>
      <translation>Le je ta določilka večja, postane ploskovje redkejše.
Razpon vrednosti je 0.2-10.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="335"/>
      <source>Elements per curvature radius:</source>
      <translation>Število elementov na polmer krivulje:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="370"/>
      <source>Whether optimization of surface shape will be done</source>
      <translation>Bodisi bo izvedena optimizacija površja oblike</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="373"/>
      <source>Optimize surface</source>
      <translation>Optimiziraj površje</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="383"/>
      <source>Whether second order elements will be generated</source>
      <translation>Bodisi bodo ustvarjene prvine drugega reda</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="386"/>
      <source>Second order elements</source>
      <translation>Prvine drugega reda</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="393"/>
      <source>Whether meshes will be arranged preferably using quadrilateral faces</source>
      <translation>Bodisi bodo ploskovja raje prirejena s pomočjo štirikotnih ploskev</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="396"/>
      <source>Quad dominated</source>
      <translation>Prevladujoče štirikotno</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="422"/>
      <source>Leave panel open</source>
      <translation>Ohrani odprto podokno</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="61"/>
      <source>Gmsh</source>
      <translation>Gmsh</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="225"/>
      <location filename="../../Tessellation.cpp" line="231"/>
      <source>No active document</source>
      <translation>Ni dejavnega dokumenta</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="259"/>
      <source>You have selected a body without tip.
Either set the tip of the body or select a different shape, please.</source>
      <translation>Izbrali ste telo brez konice.
Ali določite telesu konico ali pa izberite drugo obliko.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="263"/>
      <source>You have selected a shape without faces.
Select a different shape, please.</source>
      <translation>Izbrali ste lik brez ploskev.
Izberite drugi lik.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="267"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Najprej izberite obliko za ploskovjenje.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="198"/>
      <source>Select plane</source>
      <translation>Izberite ravnino</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="199"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Izberite ravnino s katero želite prerezati ploskovje.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location filename="../../Command.cpp" line="95"/>
      <source>Select plane</source>
      <translation>Izberite ravnino</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="96"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Izberite ravnino, s katero želite prirezati ploskovje.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Trim by plane</source>
      <translation>Prereži z ravnino</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Select the side you want to keep.</source>
      <translation>Izberite stran, ki jo želite obdržati.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Below</source>
      <translation>Pod</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Above</source>
      <translation>Nad</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Split</source>
      <translation>Razdeli</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="36"/>
      <source>MeshPart</source>
      <translation>Ploskovje</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_CreateFlatMesh</name>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="47"/>
      <source>Unwrap Mesh</source>
      <translation>Razvij ploskovje</translation>
    </message>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="50"/>
      <source>Find a flat representation of a mesh.</source>
      <translation>Iskanje ravninske predstavitve ploskovja.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_CreateFlatFace</name>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="79"/>
      <source>Unwrap Face</source>
      <translation>Razvij ploskev</translation>
    </message>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="82"/>
      <source>Find a flat representation of a face.</source>
      <translation>Iskanje ravninske predstavitve ploskve.</translation>
    </message>
  </context>
</TS>
